@@ -2,6 +2,7 @@ import tempfile
 
 from .settings_base import *  # noqa: F401 F403
 
+
 # This is a SQLite configuration, which uses a file based database for
 # tests (via setting TEST_NAME / TEST['NAME']).
 
@@ -14,7 +15,9 @@ DATABASES = {
     "default": {
         "ENGINE": "django.db.backends.sqlite3",
         "NAME": "/pytest_django_tests_default",
-        "TEST": {"NAME": _filename_default},
+        "TEST": {
+            "NAME": _filename_default,
+        },
     },
     "replica": {
         "ENGINE": "django.db.backends.sqlite3",
@@ -27,6 +30,8 @@ DATABASES = {
     "second": {
         "ENGINE": "django.db.backends.sqlite3",
         "NAME": "/pytest_django_tests_second",
-        "TEST": {"NAME": _filename_second},
+        "TEST": {
+            "NAME": _filename_second,
+        },
     },
 }
