@@ -1,4 +1,4 @@
-def test_db_access_with_repr_in_report(django_testdir):
+def test_db_access_with_repr_in_report(django_testdir) -> None:
     django_testdir.create_test_module(
         """
         import pytest
